@@ -40,6 +40,7 @@ IPROTO_ERROR = 0x52
 #
 IPROTO_VERSION = 0x54
 IPROTO_FEATURES = 0x55
+IPROTO_AUTH_TYPE = 0x5b
 IPROTO_CHUNK = 0x80
 
 IPROTO_GREETING_SIZE = 128
@@ -96,7 +97,6 @@ IPROTO_FEATURE_STREAMS = 0
 IPROTO_FEATURE_TRANSACTIONS = 1
 IPROTO_FEATURE_ERROR_EXTENSION = 2
 IPROTO_FEATURE_WATCHERS = 3
-IPROTO_FEATURE_GRACEFUL_SHUTDOWN = 4
 
 # Default value for connection timeout (seconds)
 CONNECTION_TIMEOUT = None
@@ -118,6 +118,10 @@ DEFAULT_SSL_CERT_FILE = None
 DEFAULT_SSL_CA_FILE = None
 # Default value for list of SSL ciphers
 DEFAULT_SSL_CIPHERS = None
+# Default value for SSL key file password
+DEFAULT_SSL_PASSWORD = None
+# Default value for a path to file with SSL key file password
+DEFAULT_SSL_PASSWORD_FILE = None
 # Default cluster nodes list refresh interval (seconds)
 CLUSTER_DISCOVERY_DELAY = 60
 # Default cluster nodes state refresh interval (seconds)
@@ -131,3 +135,10 @@ POOL_INSTANCE_RECONNECT_DELAY = 0
 CONNECTOR_IPROTO_VERSION = 3
 # List of connector-supported features
 CONNECTOR_FEATURES = [IPROTO_FEATURE_ERROR_EXTENSION,]
+
+# Authenticate with CHAP-SHA1 (Tarantool CE and EE)
+AUTH_TYPE_CHAP_SHA1 = "chap-sha1"
+# Authenticate with PAP-SHA256 (Tarantool EE)
+AUTH_TYPE_PAP_SHA256 = "pap-sha256"
+# List of supported auth types.
+AUTH_TYPES = [AUTH_TYPE_CHAP_SHA1, AUTH_TYPE_PAP_SHA256]
